Rename library and update build system

Change-Id: I78c6a412c5e2181e58649c0e0aa2aa2f97da16a1
diff --git a/src/algo/aes.hpp b/src/algo/aes.hpp
index d0fbabd..685ea4b 100644
--- a/src/algo/aes.hpp
+++ b/src/algo/aes.hpp
@@ -1,24 +1,24 @@
 /* -*- Mode:C++; c-file-style:"gnu"; indent-tabs-mode:nil; -*- */
 /**
- * Copyright (c) 2014-2018,  Regents of the University of California
+ * Copyright (c) 2014-2018, Regents of the University of California
  *
  * This file is part of gep (Group-based Encryption Protocol for NDN).
  * See AUTHORS.md for complete list of gep authors and contributors.
  *
  * gep is free software: you can redistribute it and/or modify it under the terms
  * of the GNU General Public License as published by the Free Software Foundation,
  * either version 3 of the License, or (at your option) any later version.
  *
- * gep is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+ * NAC is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
  * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
  * PURPOSE.  See the GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License along with
- * gep, e.g., in COPYING.md file.  If not, see <http://www.gnu.org/licenses/>.
+ * NAC, e.g., in COPYING.md file.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef NDN_GEP_ALGO_AES_HPP
-#define NDN_GEP_ALGO_AES_HPP
+#ifndef NDN_NAC_ALGO_AES_HPP
+#define NDN_NAC_ALGO_AES_HPP
 
 #include "common.hpp"
 #include "encrypt-params.hpp"
@@ -27,7 +27,7 @@
 #include <ndn-cxx/security/key-params.hpp>
 
 namespace ndn {
-namespace gep {
+namespace nac {
 namespace algo {
 
 class Aes
@@ -50,11 +50,11 @@
           const EncryptParams& params);
 };
 
-typedef DecryptKey<Aes> AesEncryptKey;
-typedef EncryptKey<Aes> AesDecryptKey;
+using AesEncryptKey = DecryptKey<Aes>;
+using AesDecryptKey = EncryptKey<Aes>;
 
 } // namespace algo
-} // namespace gep
+} // namespace nac
 } // namespace ndn
 
-#endif // NDN_GEP_ALGO_AES_HPP
+#endif // NDN_NAC_ALGO_AES_HPP
@@ -1,24 +1,24 @@
  *
- * This file is part of gep (Group-based Encryption Protocol for NDN).
- * See AUTHORS.md for complete list of gep authors and contributors.
+ * This file is part of NAC (Name-Based Access Control for NDN).
+ * See AUTHORS.md for complete list of NAC authors and contributors.
  *
@@ -1,24 +1,24 @@
  *
- * gep is free software: you can redistribute it and/or modify it under the terms
+ * NAC is free software: you can redistribute it and/or modify it under the terms
  * of the GNU General Public License as published by the Free Software Foundation,
  * either version 3 of the License, or (at your option) any later version.